@@ -35,7 +35,7 @@ with open(path.join(here, 'VERSION')) as version_file:
  Create pickle files for interpolation within various data tables
 """
 from scipy.interpolate import interp1d, NearestNDInterpolator
-from photutils import CircularAperture, aperture_photometry
+from photutils.aperture import aperture_photometry, CircularAperture
 import numpy as np
 import pickle
 from astropy.table import Table
@@ -51,12 +51,18 @@ data_path = path.join(here,'data','instrument')
 cache_path = config['DEFAULT']['data_cache_path']
 # Photometric aperture contamation calculation from PSF for make_xml_files
 pfile = path.join(cache_path,'Contamination_33arcsec_aperture.p')
-if not path.isfile(pfile):
+try:
+    psf_path = path.join(data_path, config['psf_file']['psf_file'])
+except KeyError:
+    raise KeyError("Run pycheops.core.setup_config(overwrite=True) to"
+                   " update your config file.")
+if not path.isfile(pfile) or (path.getmtime(pfile) < path.getmtime(psf_path)):
     radius = 33  # Aperture radius in pixels
-    psffile = path.join(data_path, 'CHEOPS_IT_PSFwhite_20180720AO1v1.0.txt')
-    with open(psffile) as fp:
+    psf_x0 =  config['psf_file']['x0']
+    psf_y0 =  config['psf_file']['y0']
+    with open(psf_path) as fp:
         data = [[float(digit) for digit in line.split()] for line in fp]
-    position0 = [(99.5,99.5)]
+    position0 = [psf_x0, psf_y0]
     aperture0 = CircularAperture(position0, r=radius)
     photTable0 = aperture_photometry(data, aperture0)
     target_flux = photTable0['aperture_sum'][0]
@@ -76,16 +82,26 @@ if not path.isfile(pfile):
     with open(pfile,'wb') as fp:
         pickle.dump(I,fp)
 
-# Visibility calculator for instrument.py and make_xml_files
-pfile = path.join(cache_path,'visibility_interpolator.p')
-if not path.isfile(pfile):
-    vfile = path.join(data_path,'VisibilityTable.csv')
+# Visibility calculators for instrument.py and make_xml_files
+pfile6 = path.join(cache_path,'visibility_interpolator6.p')
+pfile12 = path.join(cache_path,'visibility_interpolator12.p')
+if not path.isfile(pfile6):
+    vfile = path.join(data_path,'VisibilityTable6.csv')
     visTable = Table.read(vfile)
     ra_ = visTable['RA']*180/np.pi
     dec_ = visTable['Dec']*180/np.pi
     vis = visTable['Efficiency']
     I = NearestNDInterpolator((np.array([ra_,dec_])).T,vis)
-    with open(pfile,'wb') as fp:
+    with open(pfile6,'wb') as fp:
+        pickle.dump(I,fp)
+if not path.isfile(pfile12):
+    vfile = path.join(data_path,'VisibilityTable12.csv')
+    visTable = Table.read(vfile)
+    ra_ = visTable['RA']*180/np.pi
+    dec_ = visTable['Dec']*180/np.pi
+    vis = visTable['Efficiency']
+    I = NearestNDInterpolator((np.array([ra_,dec_])).T,vis)
+    with open(pfile12,'wb') as fp:
         pickle.dump(I,fp)
 
 # T_eff v. G_BP-G_RP colour from 
