@@ -44,11 +44,12 @@ Functions are defined in terms of the following parameters. [1]_
 * rstar      - host star radius/semi-major axis, rstar = R_*/a
 * k          - planet/star radius ratio, k = R_planet/R_star
 * tzero      - time of mid-transit (minimum on-sky star-planet separation). 
-* b          - impact parameter, b = a.cos(i)/R_star
+* b          - impact parameter, b=a.cos(i)/R_star (assuming circular orbit)
   
 .. rubric References
 .. [1] Hilditch, R.W., An Introduction to Close Binary Stars, CUP 2001.
 
+
 Functions 
 ---------
 
@@ -57,11 +58,10 @@ Functions
 from __future__ import (absolute_import, division, print_function,
                                 unicode_literals)
 from .constants import *
-import numpy as np
+from numpy import *
 from scipy.optimize import brent
 from numba import vectorize
 from uncertainties import ufloat, UFloat
-from uncertainties.umath import sqrt as usqrt
 import requests
 from .utils import mode, parprint, ellpar
 from random import sample as random_sample
@@ -75,18 +75,20 @@ from os.path import getmtime
 from .core import load_config
 from matplotlib.patches import Ellipse
 from scipy.signal import argrelextrema
+from scipy.optimize import brentq
 import warnings
 
 __all__ = [ 'a_rsun','f_m','m1sin3i','m2sin3i','asini','rhostar','g_2',
-        'K_kms','m_comp','transit_width','esolve','t2z',
-        'tperi2tzero','tzero2tperi', 'vrad', 'xyz_planet']
+           'K_kms','m_comp','transit_width','esolve','t2z',
+           'tperi2tzero','tzero2tperi','tzero2tinf','contact_points',
+           'vrad', 'xyz_planet', 'delta_t_sec']
 
-_arsun   = (GM_SunN*mean_solar_day**2/(4*np.pi**2))**(1/3.)/R_SunN
-_f_m     = mean_solar_day*1e9/(2*np.pi)/GM_SunN
-_asini   = mean_solar_day*1e3/2/np.pi/R_SunN
-_rhostar = 3*np.pi*V_SunN/(GM_SunN*mean_solar_day**2)
+_arsun   = (GM_SunN*mean_solar_day**2/(4*pi**2))**(1/3.)/R_SunN
+_f_m     = mean_solar_day*1e9/(2*pi)/GM_SunN
+_asini   = mean_solar_day*1e3/2/pi/R_SunN
+_rhostar = 3*pi*V_SunN/(GM_SunN*mean_solar_day**2)
 _model_path = join(dirname(abspath(__file__)),'data','models')
-_rho_Earth_cgs = M_EarthN/(4/3*np.pi*R_EarthN**3)/1000
+_rho_Earth_cgs = M_EarthN/(4/3*pi*R_EarthN**3)/1000
 
 config = load_config()
 _cache_path = config['DEFAULT']['data_cache_path']
@@ -153,7 +155,7 @@ def asini(K, P, ecc=0):
      :returns: a.sin(i) in solar radii
 
     """
-    return _asini * K * P *np.sqrt(1-ecc**2)
+    return _asini * K * P *sqrt(1-ecc**2)
 
 def r_star(rho, P, q=0):
     """ 
@@ -197,7 +199,7 @@ def g_2(r_2, P, K, sini=1, ecc=0):
     :returns: companion surface gravity in m.s-2
 
     """
-    return 2*np.pi*np.sqrt(1-ecc**2)*K*1e3/(P*mean_solar_day*r_2**2*sini) 
+    return 2*pi*sqrt(1-ecc**2)*K*1e3/(P*mean_solar_day*r_2**2*sini) 
 
 def K_kms(m_1, m_2, P, sini, ecc):
     """
@@ -216,7 +218,7 @@ def K_kms(m_1, m_2, P, sini, ecc):
     """
     M = m_1 + m_2
     a = a_rsun(P, M)
-    K = 2*np.pi*a*R_SunN*sini/(P*mean_solar_day*np.sqrt(1-ecc**2))/1000
+    K = 2*pi*a*R_SunN*sini/(P*mean_solar_day*sqrt(1-ecc**2))/1000
     K_1 = K * m_2/M
     K_2 = K * m_1/M
     return K_1, K_2
@@ -239,7 +241,7 @@ def m_comp(f_m, m_1, sini):
     DC = DA*m_1**2
     Q = (DA**2 - 3*DB)/9
     R = (2*DA**3 - 9*DA*DB + 27*DC)/54
-    DAA = -np.sign(R)*(np.sqrt(R**2 - Q**3) + np.abs(R))**(1/3)
+    DAA = -sign(R)*(sqrt(R**2 - Q**3) + abs(R))**(1/3)
     DBB = Q/DAA
     return DAA + DBB - DA/3
 
@@ -260,7 +262,7 @@ def transit_width(r, k, b, P=1):
 
     """
 
-    return P*np.arcsin(r*np.sqrt( ((1+k)**2-b**2) / (1-b**2*r**2) ))/np.pi
+    return P*arcsin(r*sqrt( ((1+k)**2-b**2) / (1-b**2*r**2) ))/pi
 
 #---------------
 
@@ -285,36 +287,36 @@ def esolve(M, ecc):
      >>> from numpy import pi, sin, abs, max
      >>> from numpy.random import uniform
      >>> ecc = uniform(0,1,1000)
-     >>> M = uniform(-2*np.pi,4*np.pi,1000)
+     >>> M = uniform(-2*pi,4*pi,1000)
      >>> E = esolve(M, ecc)
-     >>> maxerr = max(abs(E - ecc*sin(E) - (M % (2*np.pi)) ))
+     >>> maxerr = max(abs(E - ecc*sin(E) - (M % (2*pi)) ))
      >>> print("Maximum error = {:0.2e}".format(maxerr))
      Maximum error = 8.88e-16
 
     """
-    M = M % (2*np.pi)
+    M = M % (2*pi)
     if ecc == 0:
         return M
-    if M > np.pi:
-        M = 2*np.pi - M
+    if M > pi:
+        M = 2*pi - M
         flip = True
     else:
         flip = False
-    alpha = (3*np.pi + 1.6*(np.pi-np.abs(M))/(1+ecc) )/(np.pi - 6/np.pi)
+    alpha = (3*pi + 1.6*(pi-abs(M))/(1+ecc) )/(pi - 6/pi)
     d = 3*(1 - ecc) + alpha*ecc
     r = 3*alpha*d * (d-1+ecc)*M + M**3
     q = 2*alpha*d*(1-ecc) - M**2
-    w = (np.abs(r) + np.sqrt(q**3 + r**2))**(2/3)
+    w = (abs(r) + sqrt(q**3 + r**2))**(2/3)
     E = (2*r*w/(w**2 + w*q + q**2) + M) / d
-    f_0 = E - ecc*np.sin(E) - M
-    f_1 = 1 - ecc*np.cos(E)
-    f_2 = ecc*np.sin(E)
+    f_0 = E - ecc*sin(E) - M
+    f_1 = 1 - ecc*cos(E)
+    f_2 = ecc*sin(E)
     f_3 = 1-f_1
     d_3 = -f_0/(f_1 - 0.5*f_0*f_2/f_1)
     d_4 = -f_0/(f_1 + 0.5*d_3*f_2 + (d_3**2)*f_3/6)
     E = E -f_0/(f_1 + 0.5*d_4*f_2 + d_4**2*f_3/6 - d_4**3*f_2/24)
     if flip:
-        E =  2*np.pi - E
+        E =  2*pi - E
     return E
 
 #---------------
@@ -325,10 +327,10 @@ def t2z(t, tzero, P, sini, rstar, ecc=0, omdeg=90, returnMask=False):
 
     Optionally, return a flag/mask to indicate cases where the planet is
     further from the observer than the star, i.e., whether phases with z<1 are
-    transits (mask==True) or eclipses (mask==False)
+    transits (mask==False) or eclipses (mask==True)
 
     :param t: time of observation (scalar or array)
-    :param tzero: time of inferior conjunction, i.e., mid-transit
+    :param tzero: time of mid-transit (minimum on-sky star-planet separation)
     :param P: orbital period
     :param sini: sine of orbital inclination
     :param rstar: scaled stellar radius, R_star/a
@@ -358,30 +360,62 @@ def t2z(t, tzero, P, sini, rstar, ecc=0, omdeg=90, returnMask=False):
         
     """
     if ecc == 0:
-        nu = 2*np.pi*(t-tzero)/P
-        omrad = 0.5*np.pi
-        z = np.sqrt(1 - np.cos(nu)**2*sini**2)/rstar
+        nu = 2*pi*(t-tzero)/P
+        omrad = 0.5*pi
+        z = sqrt(1 - cos(nu)**2*sini**2)/rstar
     else:
         tp = tzero2tperi(tzero,P,sini,ecc,omdeg,return_nan_on_error=True)
-        if tp is np.nan:
+        if tp is nan:
             if returnMask:
-                return np.full_like(t,np.nan),np.full_like(t,True,dtype=np.bool)
+                return full_like(t,nan),full_like(t,True,dtype=bool)
             else:
-                return np.full_like(t,np.nan)
-        M = 2*np.pi*(t-tp)/P
+                return full_like(t,nan)
+        M = 2*pi*(t-tp)/P
         E = esolve(M,ecc)
-        nu = 2*np.arctan(np.sqrt((1+ecc)/(1-ecc))*np.tan(E/2))
-        omrad = np.pi*omdeg/180
+        nu = 2*arctan(sqrt((1+ecc)/(1-ecc))*tan(E/2))
+        omrad = pi*omdeg/180
         # Equation (5.63) from Hilditch
         z = (((1-ecc**2)/
-            (1+ecc*np.cos(nu))*np.sqrt(1-np.sin(omrad+nu)**2*sini**2))/rstar)
+            (1+ecc*cos(nu))*sqrt(1-sin(omrad+nu)**2*sini**2))/rstar)
     if returnMask:
-        return z, np.sin(nu + omrad)*sini < 0
+        return z, sin(nu + omrad)*sini < 0
     else:
         return z
 
 #---------
 
+def tzero2tinf(tzero,P,sini,ecc,omdeg):
+    """
+    Calculate time of inferior conjunction from time of mid-transit
+
+    :param tzero: time of mid-transit (minimum on-sky star-planet separation)
+    :param P: orbital period
+    :param sini: sine of orbital inclination 
+    :param ecc: eccentricity 
+    :param omdeg: longitude of periastron in degrees
+
+    :returns: time of inferior conjunction closest to tzero
+
+    :Example:
+     >>> from pycheops.funcs import tzero2tinf
+     >>> tzero = 54321.6789
+     >>> P = 1.23456
+     >>> sini = 0.987
+     >>> ecc = 0.654
+     >>> omdeg = 89.01
+     >>> print("{:0.4f}".format(tzero2tinf(tzero,P,sini,ecc,omdeg)))
+     54321.6784
+
+    """
+    # See Hilditch Sec 4.2.1
+    tperi = tzero2tperi(tzero,P,sini,ecc,omdeg)
+    theta = pi/2 - omdeg*pi/180
+    E = 2*arctan(sqrt((1-ecc)/(1+ecc))*tan(theta/2))
+    eta = E - ecc*sin(E)
+    return eta*P/(2*pi) + tperi
+
+#---------
+
 def tzero2tperi(tzero,P,sini,ecc,omdeg,
         return_nan_on_error=False):
     """
@@ -389,7 +423,7 @@ def tzero2tperi(tzero,P,sini,ecc,omdeg,
 
     Uses the method by Lacy, 1992AJ....104.2213L
 
-    :param tzero: times of mid-transit
+    :param tzero: time of mid-transit (minimum on-sky star-planet separation)
     :param P: orbital period
     :param sini: sine of orbital inclination 
     :param ecc: eccentricity 
@@ -411,30 +445,30 @@ def tzero2tperi(tzero,P,sini,ecc,omdeg,
     def _delta(th, sin2i, omrad, ecc):
         # Equation (4.9) from Hilditch
         return (1-ecc**2)*(
-                np.sqrt(1-sin2i*np.sin(th+omrad)**2)/(1+ecc*np.cos(th)))
+                sqrt(1-sin2i*sin(th+omrad)**2)/(1+ecc*cos(th)))
 
-    omrad = omdeg*np.pi/180
+    omrad = omdeg*pi/180
     sin2i = sini**2
-    theta = 0.5*np.pi-omrad
-    if (1-sin2i) > np.finfo(0.).eps :
-        ta = theta-0.125*np.pi
+    theta = 0.5*pi-omrad
+    if (1-sin2i) > finfo(0.).eps :
+        ta = theta-0.125*pi
         tb = theta
-        tc = theta+0.125*np.pi
+        tc = theta+0.125*pi
         fa = _delta(ta, sin2i, omrad, ecc)
         fb = _delta(tb, sin2i, omrad, ecc)
         fc = _delta(tc, sin2i, omrad, ecc)
         if ((fb>fa)|(fb>fc)):
-            t_ = np.linspace(0,2*np.pi,1024)
+            t_ = linspace(0,2*pi,1024)
             d_ = _delta(t_, sin2i, omrad, ecc)
             try:
-                i_= argrelextrema(d_, np.less)[0]
+                i_= argrelextrema(d_, less)[0]
                 t_ = t_[i_]
                 if len(t_)>1:
-                    i_ = (np.abs(t_ - tb)).argmin()
+                    i_ = (abs(t_ - tb)).argmin()
                     t_ = t_[i_]
                 ta,tb,tc = (t_-0.01, t_, t_+0.01)
             except:
-                if return_nan_on_error: return np.nan
+                if return_nan_on_error: return nan
                 print(sin2i, omrad, ecc)
                 print(ta, tb, tc)
                 print(fa, fb, fc)
@@ -442,17 +476,17 @@ def tzero2tperi(tzero,P,sini,ecc,omdeg,
         try:
             theta = brent(_delta, args=(sin2i, omrad, ecc), brack=(ta, tb, tc))
         except ValueError:
-            if return_nan_on_error: return np.nan
+            if return_nan_on_error: return nan
             print(sin2i, omrad, ecc)
             print(ta, tb, tc)
             print(fa, fb, fc)
             raise ValueError('Not a bracketing interval.')
 
-    if theta == np.pi:
-        E = np.pi 
+    if theta == pi:
+        E = pi 
     else:
-        E = 2*np.arctan(np.sqrt((1-ecc)/(1+ecc))*np.tan(theta/2))
-    return tzero - (E - ecc*np.sin(E))*P/(2*np.pi)
+        E = 2*arctan(sqrt((1-ecc)/(1+ecc))*tan(theta/2))
+    return tzero - (E - ecc*sin(E))*P/(2*pi)
 
 #---------
 
@@ -484,26 +518,26 @@ def tperi2tzero(tperi,P,sini,ecc,omdeg,eclipse=False):
     def _delta(th, sin2i, omrad, ecc):
         # Equation (4.9) from Hilditch
         return (1-ecc**2)*(
-                np.sqrt(1-sin2i*np.sin(th+omrad)**2)/(1+ecc*np.cos(th)))
+                sqrt(1-sin2i*sin(th+omrad)**2)/(1+ecc*cos(th)))
 
-    omrad = omdeg*np.pi/180
+    omrad = omdeg*pi/180
     sin2i = sini**2
-    theta = 0.5*np.pi-omrad + np.pi*eclipse
-    if (1-sin2i) > np.finfo(0.).eps :
-        ta = theta-0.125*np.pi
+    theta = 0.5*pi-omrad + pi*eclipse
+    if (1-sin2i) > finfo(0.).eps :
+        ta = theta-0.125*pi
         tb = theta
-        tc = theta+0.125*np.pi
+        tc = theta+0.125*pi
         fa = _delta(ta, sin2i, omrad, ecc)
         fb = _delta(tb, sin2i, omrad, ecc)
         fc = _delta(tc, sin2i, omrad, ecc)
         if ((fb>fa)|(fb>fc)):
-            t_ = np.linspace(0,2*np.pi,1024)
+            t_ = linspace(0,2*pi,1024)
             d_ = _delta(t_, sin2i, omrad, ecc)
             try:
-                i_= argrelextrema(d_, np.less)[0]
+                i_= argrelextrema(d_, less)[0]
                 t_ = t_[i_]
                 if len(t_)>1:
-                    i_ = (np.abs(t_ - tb)).argmin()
+                    i_ = (abs(t_ - tb)).argmin()
                     t_ = t_[i_]
                 ta,tb,tc = (t_-0.01, t_, t_+0.01)
             except:
@@ -519,22 +553,24 @@ def tperi2tzero(tperi,P,sini,ecc,omdeg,eclipse=False):
             print(fa, fb, fc)
             raise ValueError('Not a bracketing interval.')
 
-    if theta == np.pi:
-        E = np.pi 
+    if theta == pi:
+        E = pi 
     else:
-        E = 2*np.arctan(np.sqrt((1-ecc)/(1+ecc))*np.tan(theta/2))
-    return tperi + (E - ecc*np.sin(E))*P/(2*np.pi)
+        E = 2*arctan(sqrt((1-ecc)/(1+ecc))*tan(theta/2))
+    return tperi + (E - ecc*sin(E))*P/(2*pi)
 
 #---------------
 
-def eclipse_phase (P,sini,ecc,omdeg):
+def eclipse_phase (sini,ecc,omdeg):
     """
-    Calculate time of mid-transit/mid-eclipse from time of periastron
+    Calculate phase of mid-eclipse from time of mid-transit
 
     Uses the method by Lacy, 1992AJ....104.2213L
 
-    :param tzero: times of mid-transit
-    :param P: orbital period
+    Time of mid-transit is time of minimum on-sky star-planet separation.
+
+    Does not include correction for light travel time (see delta_t_sec).
+
     :param sini: sine of orbital inclination 
     :param ecc: eccentricity 
     :param omdeg: longitude of periastron in degrees
@@ -543,17 +579,15 @@ def eclipse_phase (P,sini,ecc,omdeg):
 
     :Example:
      >>> from pycheops.funcs import eclipse_phase
-     >>> P = 1.23456
      >>> sini = 0.987
      >>> ecc = 0.654
      >>> omdeg = 89.01
-     >>> ph_ecl = eclipse_phase(tzero,P,sini,ecc,omdeg)
+     >>> ph_ecl = eclipse_phase(sini,ecc,omdeg)
      >>> print(f"Phase of eclipse = {ph_ecl:0.4f}")
 
     """
-    t_peri = tzero2tperi(0,P,sini,ecc,omdeg)
-    t_ecl = tperi2tzero(t_peri,P,sini,ecc,omdeg,eclipse=True)
-    return t_ecl/P % 1
+    t_peri = tzero2tperi(0,1,sini,ecc,omdeg)
+    return tperi2tzero(t_peri,1,sini,ecc,omdeg,eclipse=True) % 1
 
 #---------------
 
@@ -573,7 +607,7 @@ def nu_max(Teff, logg):
     .. [2] Campante, 2016, ApJ 830, 138.
 
     """
-    return 3090 * 10**(logg-4.438)/np.sqrt(Teff/5777)
+    return 3090 * 10**(logg-4.438)/sqrt(Teff/5777)
 
 
 #---------------
@@ -583,7 +617,7 @@ def vrad(t,tzero,P,K,ecc=0,omdeg=90,sini=1, primary=True):
     Calculate radial velocity, V_r, for body in a Keplerian orbit
 
     :param t: array of input times 
-    :param tzero: time of inferior conjunction, i.e., mid-transit
+    :param tzero: time of mid-transit (minimum on-sky star-planet separation)
     :param P: orbital period
     :param K: radial velocity semi-amplitude 
     :param ecc: eccentricity (optional, default=0)
@@ -595,13 +629,13 @@ def vrad(t,tzero,P,K,ecc=0,omdeg=90,sini=1, primary=True):
 
     """
     tp = tzero2tperi(tzero,P,sini,ecc,omdeg)
-    M = 2*np.pi*(t-tp)/P
+    M = 2*pi*(t-tp)/P
     E = esolve(M,ecc)
-    nu = 2*np.arctan(np.sqrt((1+ecc)/(1-ecc))*np.tan(E/2))
-    omrad = np.pi*omdeg/180
+    nu = 2*arctan(sqrt((1+ecc)/(1-ecc))*tan(E/2))
+    omrad = pi*omdeg/180
     if not primary:
-        omrad = omrad + np.pi
-    return K*(np.cos(nu+omrad)+ecc*np.cos(omrad))
+        omrad = omrad + pi
+    return K*(cos(nu+omrad)+ecc*cos(omrad))
 
 #---------------
 
@@ -613,7 +647,7 @@ def xyz_planet(t, tzero, P, sini, ecc=0, omdeg=90):
     semi-major axis is taken to be a=1.
 
     :param t: time of observation (scalar or array)
-    :param tzero: time of inferior conjunction, i.e., mid-transit
+    :param tzero: time of mid-transit (minimum on-sky star-planet separation)
     :param P: orbital period
     :param sini: sine of orbital inclination
     :param ecc: eccentricity (optional, default=0)
@@ -639,23 +673,23 @@ def xyz_planet(t, tzero, P, sini, ecc=0, omdeg=90):
         
     """
     if ecc == 0:
-        nu = 2*np.pi*(t-tzero)/P
+        nu = 2*pi*(t-tzero)/P
         r = 1
         cosw = 0
         sinw = -1
     else:
         tp = tzero2tperi(tzero,P,sini,ecc,omdeg)
-        M = 2*np.pi*(t-tp)/P
+        M = 2*pi*(t-tp)/P
         E = esolve(M,ecc)
-        nu = 2*np.arctan(np.sqrt((1+ecc)/(1-ecc))*np.tan(E/2))
-        r = (1-ecc**2)/(1+ecc*np.cos(nu))
-        omrad = np.pi*omdeg/180
+        nu = 2*arctan(sqrt((1+ecc)/(1-ecc))*tan(E/2))
+        r = (1-ecc**2)/(1+ecc*cos(nu))
+        omrad = pi*omdeg/180
         # negative here since om_planet = om_star + pi
-        cosw = -np.cos(omrad)
-        sinw = -np.sin(omrad)
-    sinv = np.sin(nu) 
-    cosv = np.cos(nu)
-    cosi = np.sqrt(1-sini**2)
+        cosw = -cos(omrad)
+        sinw = -sin(omrad)
+    sinv = sin(nu) 
+    cosv = cos(nu)
+    cosi = sqrt(1-sini**2)
     x = r*(-sinv*sinw + cosv*cosw)
     y = r*cosi*(cosv*sinw + sinv*cosw)
     z = -r*sini*(cosw*sinv + cosv*sinw)
@@ -793,19 +827,19 @@ def massradius(P=None, k=None, sini=None, ecc=None,
     # Generate a sample of values for a parameter
     def _s(x, nm=NM):
         if isinstance(x,float) or isinstance(x,int):
-            return np.full(nm, x, dtype=np.float)
+            return full(nm, x, dtype=float)
         elif isinstance(x, UFloat):
-            return np.random.normal(x.n, x.s, nm)
-        elif isinstance(x, np.ndarray):
+            return random.normal(x.n, x.s, nm)
+        elif isinstance(x, ndarray):
             if len(x) == nm:
                 return x
             elif len(x) > nm:
                 return x[random_sample(range(len(x)), nm)]
             else:
-                return x[(np.random.random(nm)*len(x+1)).astype(int)]
+                return x[(random.random(nm)*len(x+1)).astype(int)]
         elif isinstance(x, tuple):
             if len(x) == 2:
-                return np.random.normal(x[0], x[1], nm)
+                return random.normal(x[0], x[1], nm)
             elif len(x) == 3:
                 raise NotImplementedError
         raise ValueError("Unrecognised type for parameter values")
@@ -816,7 +850,7 @@ def massradius(P=None, k=None, sini=None, ecc=None,
         d['mean'] = x.mean()
         d['stderr'] = x.std()
         d['mode'] = mode(x)
-        q = np.percentile(x, [5,15.8655,50,84.1345,95])
+        q = percentile(x, [5,15.8655,50,84.1345,95])
         d['median'] = q[2]
         d['e_hi'] = q[3]-q[2]
         d['e_lo'] = q[2]-q[1]
@@ -828,24 +862,24 @@ def massradius(P=None, k=None, sini=None, ecc=None,
     fig = None
 
     # Use e=0 if input value is none, otherwise sample in the range [0,1)
-    _e = 0 if ecc is None else np.clip(np.abs(_s(ecc)),0,0.999999)
+    _e = 0 if ecc is None else clip(abs(_s(ecc)),0,0.999999)
 
     # Look for input values that are numpy arrays of the same length, in which
     # case sample these together.
     pv = [P, k, sini, _e, m_star, r_star, K, aR]
     pn = ['P', 'k', 'sini', 'e', 'm_star', 'r_star', 'K', 'aR']
     ps = {}  # dictionary of samples for each input parameter
-    _n = [len(p) if isinstance(p, np.ndarray) else 0 for p in pv]
-    _u = np.unique(_n)
+    _n = [len(p) if isinstance(p, ndarray) else 0 for p in pv]
+    _u = unique(_n)
     for _m in _u[_u>0]:
-        _i = np.where(_n == _m)[0]
+        _i = where(_n == _m)[0]
         if len(_i) > 1:
             if _m == NM:
                 _j = range(_m)
             elif _m > NM:
                 _j = random_sample(range(_m), NM)
             else:
-                _j = (np.random.random(NM)*_m).astype(int)
+                _j = (random.random(NM)*_m).astype(int)
             for _k in _i:
                 ps[pn[_k]] = pv[_k][_j]
 
@@ -854,7 +888,7 @@ def massradius(P=None, k=None, sini=None, ecc=None,
     # avoid negative values.
     for n in set(pn) - set(ps.keys()):
         _i = pn.index(n)
-        ps[n] = None if pv[_i] is None else np.abs(_s(pv[_i]))
+        ps[n] = None if pv[_i] is None else abs(_s(pv[_i]))
 
     if jovian:
         if solar: raise ValueError("Cannot specify both jovian and solar units")
@@ -924,20 +958,20 @@ def massradius(P=None, k=None, sini=None, ecc=None,
         result['g_p'] = _d(ps['g_p'])
         if verbose:
             print(parprint(ps['g_p'],'g_p',wn=8,w=10) + ' m.s-2')
-            _loggp = np.log10(ps['g_p'])+2
+            _loggp = log10(ps['g_p'])+2
             print(parprint(_loggp,'log g_p',wn=8,w=10)+' [cgs]')
         if m_star is not None:
             _rho = (3 * ps['g_p']**1.5 / 
-                    ( 4*np.pi * G_2014**1.5 * (ps['_mp']*M_SunN)**0.5) )
+                    ( 4*pi * G_2014**1.5 * (ps['_mp']*M_SunN)**0.5) )
             if jovian:
-                rho_Jup  = M_JupN / (4/3*np.pi*R_JupN**3)
+                rho_Jup  = M_JupN / (4/3*pi*R_JupN**3)
                 ps['rho_p'] = _rho/rho_Jup
                 rhostr = ' rho_Jup'
             elif solar:
                 ps['rho_p'] = _rho
                 rhostr = ' rho_Sun'
             else:
-                rho_Earth  = M_EarthN / (4/3*np.pi*R_EarthN**3)
+                rho_Earth  = M_EarthN / (4/3*pi*R_EarthN**3)
                 ps['rho_p'] = _rho/rho_Earth
                 rhostr = ' rho_Earth'
             if verbose:
@@ -1044,8 +1078,8 @@ def massradius(P=None, k=None, sini=None, ecc=None,
                     print('TEPCat data downloaded from \n {}'.format(url))
         # Awkward table to deal with because of repeated column names
         T = Table.read(TEPCatPath,format='ascii.no_header')
-        M_b=np.array(T[T.colnames[list(T[0]).index('M_b')]][1:],dtype=np.float)
-        R_b=np.array(T[T.colnames[list(T[0]).index('R_b')]][1:],dtype=np.float)
+        M_b=array(T[T.colnames[list(T[0]).index('M_b')]][1:],dtype=float)
+        R_b=array(T[T.colnames[list(T[0]).index('R_b')]][1:],dtype=float)
         ok = (M_b > 0) & (R_b > 0)
         M_b = M_b[ok]
         R_b = R_b[ok]
@@ -1067,7 +1101,117 @@ def massradius(P=None, k=None, sini=None, ecc=None,
     if ellipse:
         for nsig in ell_sigma:
             xy, w, h, theta = ellpar(ps['m_p'],ps['r_p'],nsig)
-            ax.add_patch(Ellipse(xy, w, h, theta, **ell_kws))
+            ax.add_patch(Ellipse(xy, w, h, angle=theta, **ell_kws))
 
     return result, fig
         
+
+#---------------
+
+def contact_points(tzero, P, rstar, k, sini, ecc, omdeg, M, q=0):
+    """
+    Calculate times of 1st, 2nd, 3rd and 4th contact for transit and eclipse 
+
+    Times are returned as np.nan if no such contact point exists, e.g for
+    partial eclipses.
+
+    Includes calculation of light travel time across the orbit for the eclipse
+
+    :param tzero: time of mid-transit (minimum on-sky star-planet separation)
+    :param P: orbital period in days
+    :param rstar: scaled stellar radius, R_star/a
+    :param k: R_planet/R_star
+    :param sini: sine of orbital inclination (optional, default 1)
+    :param ecc: eccentricity (optional, default=0)
+    :param omdeg: longitude of periastron in degrees (optional, default=90)
+    :param M: primary star mass in solar masses 
+    :param q: mass ratio = M_companion/M_star (optional, default 0)
+
+    N.B. omdeg is the longitude of periastron for the primary star's orbit
+
+    :returns: dict of contact points, t1-t4 for transit, t5-t8 for eclipse
+
+    :Example:
+
+    HD 80606
+
+    >>> tzero = 2458888.07466
+    >>> P = 111.436765
+    >>> sini = sin(radians(89.24))
+    >>> ecc = 0.93183
+    >>> omdeg = -58.887
+    >>> rstar = 1/94.452
+    >>> k = sqrt(0.01019)
+    >>> M = 1.05
+    >>> c = contact_points(tzero, P, rstar, k, sini, ecc, omdeg, M)
+    >>> t14 = c['t4']-c['t1']
+    >>> t58 = c['t8']-c['t5']
+    >>> print(f'Transit duration = {t14:0.3f} d')
+    Transit duration = 0.499 d
+    >>> print(f'Eclipse duration = {t58:0.3f} d')
+    Eclipse duration = 0.083 d
+
+    """
+    def _f1_(t):
+        return t2z(t, tzero, P, sini, rstar, ecc, omdeg) - (1+k)
+    def _f2_(t):
+        return t2z(t, tzero, P, sini, rstar, ecc, omdeg) - (1-k)
+
+    r = dict(zip([f't{i+1}' for i in range(8)],[nan]*8))
+    t = linspace(tzero-P/4,tzero+P/4, 65536) 
+    dt = ptp(t)/65535
+    z,m = t2z(t, tzero, P, sini, rstar, ecc, omdeg, returnMask=True)
+    if min(z[~m]) < (1+k):
+        ta = max(t[~m & (t < tzero) & (z > (1+k))])
+        r['t1'] = brentq(_f1_,ta,ta+dt)
+        tb = min(t[~m & (t > tzero) & (z > (1+k))])
+        r['t4'] = brentq(_f1_,tb-dt,tb)
+    if min(z[~m]) < (1-k):
+        ta = max(t[~m & (t < tzero) & (z > (1-k))])
+        r['t2'] = brentq(_f2_,ta,ta+dt)
+        tb = min(t[~m & (t > tzero) & (z > (1-k))])
+        r['t3'] = brentq(_f2_,tb-dt,tb)
+    tsec = tzero + P*eclipse_phase(sini, ecc, omdeg)
+    t = linspace(tsec-P/4,tsec+P/4,65536) 
+    ltt = delta_t_sec(P, M, sini, ecc, omdeg, q)/86400
+    z,m = t2z(t, tzero, P, sini, rstar, ecc, omdeg, returnMask=True)
+    if min(z[m]) < (1+k):
+        ta = max(t[m & (t < tsec) & (z > (1+k))])
+        r['t5'] = brentq(_f1_,ta,ta+dt) + ltt
+        tb = min(t[m & (t > tsec) & (z > (1+k))])
+        r['t8'] = brentq(_f1_,tb-dt,tb) + ltt
+    if min(z[m]) < (1-k):
+        ta = max(t[m & (t < tsec) & (z > (1-k))])
+        r['t6'] = brentq(_f2_,ta,ta+dt) + ltt
+        tb = min(t[m & (t > tsec) & (z > (1-k))])
+        r['t7'] = brentq(_f2_,tb-dt,tb) + ltt
+    return r
+
+#---------------
+
+def delta_t_sec(P, M=1, sini=1, ecc=0, omdeg=90, q=0):
+    """
+    Correction to time of mid-eclipse due to light travel time.
+
+    From Borkovits, et al. 2015MNRAS.448..946B, equation (25)
+
+    :param P: orbital period in days
+    :param M: primary star mass in solar masses (optional, default 1)
+    :param sini: sine of orbital inclination (optional, default 1)
+    :param ecc: eccentricity (optional, default=0)
+    :param omdeg: longitude of periastron in degrees (optional, default=90)
+    :param q: mass ratio = M_companion/M_star (optional, default 0)
+
+    N.B. omdeg is the longitude of periastron for the primary star's orbit
+
+    :returns: light travel time correction in seconds
+
+    """
+
+    asini = a_rsun(P, M*(1+q))*R_SunN*sini
+    esinw = ecc*sin(radians(omdeg))
+    return 2*(1-q)/(1+q)*asini*(1-ecc**2)/(1-esinw**2)/c
+
+
+
+
