@@ -33,8 +33,8 @@ import numpy as np
 
 from os.path import join,abspath,dirname,isfile
 import pickle 
-from numpy import int as np_int 
 from astropy.table import Table
+from astropy.coordinates import SkyCoord
 from .core import load_config
 from .models import TransitModel, scaled_transit_fit, minerr_transit_fit
 import warnings 
@@ -52,14 +52,17 @@ PSF_R90 = 16.2
 PSF_HP = 0.0046
 FWC = 114000
 
-# From Benz et al., 2020
-CHEOPS_ORBIT_MINUTES = 98.725
+# From CH_TU2024-03-12T10-00-00_EXT_APP_ObservationRequests_V0003.xml
+CHEOPS_ORBIT_MINUTES = 98.77
 
 with open(join(_cache_path,'C_G_Teff_interpolator.p'),'rb') as fp:
     _C_G_Teff_interpolator = pickle.load(fp)
 
-with open(join(_cache_path,'visibility_interpolator.p'),'rb') as fp:
-    _visibility_interpolator = pickle.load(fp)
+with open(join(_cache_path,'visibility_interpolator6.p'),'rb') as fp:
+    _visibility_interpolator6 = pickle.load(fp)
+
+with open(join(_cache_path,'visibility_interpolator12.p'),'rb') as fp:
+    _visibility_interpolator12 = pickle.load(fp)
 
 _cadence_Table = Table.read(join(_data_path,'instrument','cadence.csv'),
         format='ascii.csv', header_start=1)
@@ -93,24 +96,46 @@ def count_rate(G, Teff=6000):
 
 #-----------------------------
 
-def visibility(ra, dec):
+def visibility(ra, dec, Gmag):
     """
     Estimate of target visibility 
 
-    The target visibility estimated with this function is approximate. A more
-    reliable estimate of the observing efficiency can be made with the 
-    Feasibility Checker tool.
+    The visibility is based on two maps computed using various assumptions,
+    one for Gmag=6 and one for Gmag=12. The efficiency for Gmag = 6 represents
+    the best-case scenario for targets in the 6 < mag < 9 range, while the
+    efficiency for Gmag = 12 represents the worst-case scenario for targets
+    with mag > 9.
 
     :param ra: right ascension in degrees (scalar or array)
 
     :param dec: declination in degrees (scalar or array)
 
+    :param Gmag: target G-band magnitude
+
     :returns: target visibility (%)
 
     """
 
-    return (_visibility_interpolator(ra, dec)*100).astype(np_int)
+    if Gmag > 9:
+        vis =  (_visibility_interpolator12(ra, dec)*100).astype(int)
+    else:
+        vis =  (_visibility_interpolator6(ra, dec)*100).astype(int)
 
+    # Check if |ecliptic latitude| > 60 - never visible
+    # (CHEOPS-UGE-PSO-MAN-001  section 1.3.2)  
+    # Update Jan 2025 - SEA decreased to 117 degrees so increase this limit to
+    # 63 degrees
+    # Update Jul 2025 - SEA decreased to 116.5 degrees so increase this limit to
+    # 63.5 degrees
+    # Update Oct 2026 - SEA decreased to 115 degrees so increase this limit to
+    # 65 degrees
+    coo = SkyCoord(ra, dec, unit='degree')
+    if np.isscalar(vis):
+        if abs(coo.barycentrictrueecliptic.lat.degree) > 65:
+            vis = 0
+    else:
+        vis[abs(coo.barycentrictrueecliptic.lat.degree) > 65] = 0
+    return vis
 
 #-----------------------------
 
@@ -118,12 +143,9 @@ def response(passband='CHEOPS'):
     """
      Instrument response functions.
 
-     The response functions have been digitized from Fig. 2 of
-     https://www.cosmos.esa.int/web/cheops/cheops-performances
-
      The available passband names are 'CHEOPS', 'MOST', 
-     'Kepler', 'CoRoT', 'Gaia', 'B', 'V', 'R', 'I',
-     'u\_','g\_','r\_','i\_','z\_', and 'NGTS'
+     'Kepler', 'CoRoT', 'Gaia', 'U', 'B', 'V', 'R', 'I',
+     'u\_','g\_','r\_','i\_','z\_', 'NGTS', 'TESS' and 'PLATO'
 
      :param passband: instrument/passband names (case sensitive).
 
