@@ -100,30 +100,34 @@ WHERE CONTAINS(POINT('ICRS',gaiadr2.gaia_source.ra,gaiadr2.gaia_source.dec), \
 
 # XML strings and formats for input for Feasibility checker and PHT2
 _xml_time_critical_fmt = """<?xml version="1.0" encoding="UTF-8"?>
-<!--                                                                          -->
-<!--         This file contains time-critical observations                    -->
-<!--                                                                          -->
-<!--         Generated by pycheops.make_xml_files                             -->
-<!--                                                                          -->
+<!--                                                                                     -->
+<!--         Template Observation Request file v. 11.12.1                                -->
+<!--                                                                                     -->
+<!--         This file can be ingested in the CHEOPS Feasibility Checker v11.12.1        -->
+<!--                                                                                     -->
+<!--         File prepared by CHEOPS SOC - UGE - NBI - Feb. 13, 2024                     -->
+<!--                                                                                     -->
+<!--         Generated by pycheops.make_xml_files version {}                          -->
+<!--                                                                                     -->
 <Earth_Explorer_File xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="ext_app_observation_requests_schema.xsd">
   <Earth_Explorer_Header>
     <Fixed_Header>
-      <File_Name>CH_TU2018-03-05T10-00-00_EXT_APP_ObservationRequests_V1234</File_Name>
+      <File_Name>CH_TU2024-03-12T10-00-00_EXT_APP_ObservationRequests_V0003</File_Name>
       <File_Description>Observation requests file</File_Description>
-      <Notes>Template file for CHEOPS observation Request : PHT2, FeasibilityChecker, CHEOPSim</Notes>
+      <Notes>Template file for CHEOPS observation Request : FeasibilityChecker (phase-1) and PHT2 (phase-2)</Notes>
       <Mission>CHEOPS</Mission>
       <File_Class>TEST</File_Class>
       <File_Type>EXT_APP_ObservationRequests</File_Type>
       <Validity_Period>
-        <Validity_Start>UTC=2017-01-01T00:00:00</Validity_Start>
-        <Validity_Stop>UTC=2023-01-01T00:00:00</Validity_Stop>
+        <Validity_Start>UTC=2024-03-12T00:00:00</Validity_Start>
+        <Validity_Stop>UTC=2028-12-31T00:00:00</Validity_Stop>
       </Validity_Period>
-      <File_Version>0001</File_Version>
+      <File_Version>0003</File_Version>
       <Source>
-       <System>PSO</System>
-       <Creator>PHT2</Creator>
-       <Creator_Version>000</Creator_Version>
-       <Creation_Date>UTC={}</Creation_Date>
+        <System>PSO</System>
+        <Creator>PHT2</Creator>
+        <Creator_Version>000</Creator_Version>
+        <Creation_Date>UTC={}</Creation_Date>
       </Source>
     </Fixed_Header>
     <Variable_Header>
@@ -133,45 +137,91 @@ _xml_time_critical_fmt = """<?xml version="1.0" encoding="UTF-8"?>
   
   <Data_Block type="xml">
 
-    <!-- TIME-CRITICAL REQUEST  -->
+    <!-- TIME-CRITICAL REQUEST -->
     <List_of_Time_Critical_Requests count="1">
-      <Time_Critical_Request>
-        <Programme_ID>{:d}</Programme_ID>
-        <Observation_Request_ID>1</Observation_Request_ID>
-        <Observation_Category>time critical</Observation_Category>
-        <Proprietary_Period_First_Visit unit="days">{:d}</Proprietary_Period_First_Visit>
-        <Proprietary_Period_Last_Visit unit="days">{:d}</Proprietary_Period_Last_Visit>
-        <Target_Name>{}</Target_Name>
-        <Gaia_ID>GAIA DR2 {}</Gaia_ID>
-        <Spectral_Type>{}</Spectral_Type>
-        <Target_Magnitude unit="mag">{:0.2f}</Target_Magnitude>
-        <Target_Magnitude_Error unit="mag">{:0.2f}</Target_Magnitude_Error>
-        <Readout_Mode>{}</Readout_Mode>
-        <Right_Ascension unit="deg">{:0.7f}</Right_Ascension>
-        <Declination unit="deg">{:0.7f}</Declination>
-        <RA_Proper_Motion unit="mas/year">{:0.2f}</RA_Proper_Motion>
-        <DEC_Proper_Motion unit="mas/year">{:0.2f}</DEC_Proper_Motion>
-        <Parallax unit="mas">{:0.2f}</Parallax>
-        <T_Eff unit="Kelvin">{:0.0f}</T_Eff>
-        <Extinction unit="mag">0.00</Extinction>
-        <Earliest_Start unit="BJD">{:0.3f}</Earliest_Start>
-        <Latest_End unit="BJD">{:0.3f}</Latest_End>
-        <Exposure_Time unit="sec">{:0.2f}</Exposure_Time>
-        <Number_Stacked_Images>{:d}</Number_Stacked_Images>
-        <Number_Stacked_Imagettes>{:d}</Number_Stacked_Imagettes>
-        <Transit_Time unit="BJD">{:0.6f}</Transit_Time>
-        <Transit_Period unit="days">{:0.6f}</Transit_Period>
-        <Visit_Duration unit="sec">{:0.1f}</Visit_Duration>
-        <Number_of_Visits>{:d}</Number_of_Visits>
-        <Continuous_Visits>false</Continuous_Visits>   <!--  Irrelevant for nominal science observations  -->
-        <Priority>{:d}</Priority>
-        <Minimum_Effective_Duration unit="%">{:d}</Minimum_Effective_Duration>
-        <Earliest_Observation_Start unit="phase">{:0.4f}</Earliest_Observation_Start>
-        <Latest_Observation_Start unit="phase">{:0.4f}</Latest_Observation_Start>
-        <Send_Data_Taking_During_SAA>false</Send_Data_Taking_During_SAA>
-        <Send_Data_Taking_During_Earth_Constraints>false</Send_Data_Taking_During_Earth_Constraints>
-        <PITL>true</PITL>
-      </Time_Critical_Request>
+            <Time_Critical_Request>
+                <Programme_ID>{:d}</Programme_ID>
+                
+            <Observation_Request_ID>1</Observation_Request_ID>
+                
+            <Observation_Category>time critical</Observation_Category>
+                
+            <Proprietary_Period_First_Visit unit="days">{:d}</Proprietary_Period_First_Visit>
+                
+            <Proprietary_Period_Last_Visit unit="days">{:d}</Proprietary_Period_Last_Visit>
+
+            <Target_Name>{}</Target_Name>
+              
+                <Gaia_ID>GAIA DR2 {}</Gaia_ID>
+                
+                <Spectral_Type>{}</Spectral_Type>
+                
+            <Target_Magnitude unit="mag">{:0.3f}</Target_Magnitude>
+                
+                <Target_Magnitude_Error unit="mag">{:0.3f}</Target_Magnitude_Error>
+
+                <Readout_Mode>{}</Readout_Mode>
+
+            <Right_Ascension unit="deg">{:0.7f}</Right_Ascension>
+                
+            <Declination unit="deg">{:0.7f}</Declination>
+                
+                <RA_Proper_Motion unit="mas/year">{:0.3f}</RA_Proper_Motion>
+                
+                <DEC_Proper_Motion unit="mas/year">{:0.3f}</DEC_Proper_Motion>
+                
+                <Parallax unit="mas">{:0.2f}</Parallax>
+                
+                <T_Eff unit="Kelvin">{:0.0f}</T_Eff>
+                
+                <Extinction unit="mag">0.0</Extinction>
+                
+                <Earliest_Start unit="BJD">{:0.3f}</Earliest_Start>
+
+                <Latest_End unit="BJD">{:0.3f}</Latest_End>
+                       
+                <Exposure_Time unit="sec">{:0.2f}</Exposure_Time>
+                
+            <Number_Stacked_Images>{:d}</Number_Stacked_Images>
+
+                <Number_Stacked_Imagettes>{:d}</Number_Stacked_Imagettes>
+
+            <Transit_Time unit="BJD">{:0.6f}</Transit_Time>
+                
+                <Transit_Period unit="days">{:0.8f}</Transit_Period>
+			
+                <Visit_Duration unit="sec">{:0.0f}</Visit_Duration>
+
+                <Number_of_Visits>{:d}</Number_of_Visits>
+
+                <Continuous_Visits>false</Continuous_Visits>
+                
+                <Priority>{:d}</Priority>
+
+
+                    <!-- This parameter defines the minimum on-source time relative to the visit duration                                                 -->
+                    <!--       (excluding interruptions due to the SAA, Earth Occultations, and straylight constraints)                                   -->
+                    <!-- NOTE: For visits with scheduling flexibility, especially those shorter than 3 orbits, the effective                              -->
+                    <!--       observing efficiency may end up to be lower than the requested value by up to ~ 15%.                                       -->
+                    <!--       This may happen under special circumstances, typically when the scheduleSolver algorithm adjusts                           -->
+                    <!--       the visit start time to optimise the overhall schedule, which may result in a visit being shifted                          -->
+                    <!--       toward the SAA, Earth occultations or straylight regions.                                                                  -->
+                <Minimum_Effective_Duration unit="%">{:d}</Minimum_Effective_Duration>
+
+                    <!--  This parameter defines the flexibility of a visit start time in units of planetary orbital phase.                               -->
+                    <!--        Two values are defined to bound the allowed start time of the visit.                                                      -->
+                    <!--  NOTE: Leaving no slack for the observation start time reduces the chance of being scheduled                                     -->
+                    <!--  NOTE: Requesting flexibility on the start time implies that the effective observing efficiency may in some rare cases           -->
+                    <!--        be lower than the requested value (see comment above in <Minimum_Effective_Duration>)                                     -->
+                <Earliest_Observation_Start unit="phase">{:0.5f}</Earliest_Observation_Start>
+                <Latest_Observation_Start unit="phase">{:0.5f}</Latest_Observation_Start>
+
+                {}
+
+            <Send_Data_Taking_During_SAA>false</Send_Data_Taking_During_SAA>
+            <Send_Data_Taking_During_Earth_Constraints>false</Send_Data_Taking_During_Earth_Constraints>
+            <PITL>{}</PITL>
+		</Time_Critical_Request>
     </List_of_Time_Critical_Requests>
   </Data_Block>
 </Earth_Explorer_File>
@@ -179,29 +229,36 @@ _xml_time_critical_fmt = """<?xml version="1.0" encoding="UTF-8"?>
 
 
 _xml_non_time_critical_fmt = """<?xml version="1.0" encoding="UTF-8"?>
-<!--                                                               -->
-<!--  This file contains non-time-critical observations            -->
-<!--                                                               -->
-<!--  Generated by pycheops.make_xml_files                         -->
-<!--                                                               -->
+<!--                                                                                     -->
+<!--         Template Observation Request file v. 11.12.1                                -->
+<!--                                                                                     -->
+<!--         This file can be ingested in the CHEOPS Feasibility Checker v11.12.1        -->
+<!--                                                                                     -->
+<!--         This version of the file contains an example of                             -->
+<!--          how to set up a non-time-critical observation                              -->
+<!--                                                                                     -->
+<!--         File prepared by CHEOPS SOC - UGE - NBI - Feb. 13, 2024                     -->
+<!--                                                                                     -->
+<!--         Generated by pycheops.make_xml_files version {}                          -->
+<!--                                                                                     -->
 <Earth_Explorer_File xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="ext_app_observation_requests_schema.xsd">
   <Earth_Explorer_Header>
     <Fixed_Header>
-      <File_Name>CH_TU2018-03-05T10-00-00_EXT_APP_ObservationRequests_V1234</File_Name>
+      <File_Name>CH_TU2024-03-12T10-00-00_EXT_APP_ObservationRequests_V0004</File_Name>
       <File_Description>Observation requests file</File_Description>
-      <Notes>Template file for CHEOPS observation Request : PHT2, FeasibilityChecker, CHEOPSim</Notes>
+      <Notes>Template file for CHEOPS observation Request : FeasibilityChecker (phase-1) and PHT2 (phase-2)</Notes>
       <Mission>CHEOPS</Mission>
       <File_Class>TEST</File_Class>
       <File_Type>EXT_APP_ObservationRequests</File_Type>
       <Validity_Period>
-        <Validity_Start>UTC=2017-01-01T00:00:00</Validity_Start>
-        <Validity_Stop>UTC=2023-01-01T00:00:00</Validity_Stop>
+        <Validity_Start>UTC=2024-03-12T00:00:00</Validity_Start>
+        <Validity_Stop>UTC=2028-12-31T00:00:00</Validity_Stop>
       </Validity_Period>
-      <File_Version>0001</File_Version>
+      <File_Version>0004</File_Version>
       <Source>
-       <System>PSO</System>
-       <Creator>PHT2</Creator>
-       <Creator_Version>000</Creator_Version>
+        <System>PSO</System>
+        <Creator>PHT2</Creator>
+        <Creator_Version>000</Creator_Version>
        <Creation_Date>UTC={}</Creation_Date>
       </Source>
     </Fixed_Header>
@@ -215,36 +272,64 @@ _xml_non_time_critical_fmt = """<?xml version="1.0" encoding="UTF-8"?>
     <List_of_Non_Time_Critical_Requests count="1">
       <Non_Time_Critical_Request>
         <Programme_ID>{:d}</Programme_ID>
+              
         <Observation_Request_ID>1</Observation_Request_ID>
+              
         <Observation_Category>non time critical</Observation_Category>
+              
         <Proprietary_Period_First_Visit unit="days">{:d}</Proprietary_Period_First_Visit>
+              
         <Proprietary_Period_Last_Visit unit="days">{:d}</Proprietary_Period_Last_Visit>
+              
         <Target_Name>{}</Target_Name>
+              
         <Gaia_ID>GAIA DR2 {}</Gaia_ID>
+              
         <Spectral_Type>{}</Spectral_Type>
-        <Target_Magnitude unit="mag">{:0.2f}</Target_Magnitude>
-        <Target_Magnitude_Error unit="mag">{:0.2f}</Target_Magnitude_Error>
+              
+        <Target_Magnitude unit="mag">{:0.3f}</Target_Magnitude>
+              
+        <Target_Magnitude_Error unit="mag">{:0.3f}</Target_Magnitude_Error>
+              
         <Readout_Mode>{}</Readout_Mode>
+              
         <Right_Ascension unit="deg">{:0.5f}</Right_Ascension>
+              
         <Declination unit="deg">{:0.5f}</Declination>
+              
         <RA_Proper_Motion unit="mas/year">{:0.2f}</RA_Proper_Motion>
+              
         <DEC_Proper_Motion unit="mas/year">{:0.2f}</DEC_Proper_Motion>
+              
         <Parallax unit="mas">{:0.2f}</Parallax>
+              
         <T_Eff unit="Kelvin">{:0.0f}</T_Eff>
+              
         <Extinction unit="mag">0.00</Extinction>
+              
         <Earliest_Start unit="BJD">{:0.3f}</Earliest_Start>
+              
         <Latest_End unit="BJD">{:0.3f}</Latest_End>
+              
         <Exposure_Time unit="sec">{:0.2f}</Exposure_Time>
+              
         <Number_Stacked_Images>{:d}</Number_Stacked_Images>
+              
         <Number_Stacked_Imagettes>{:d}</Number_Stacked_Imagettes>
-        <Visit_Duration unit="sec">{:0.1f}</Visit_Duration>
+              
+        <Visit_Duration unit="sec">{:0.0f}</Visit_Duration>
+              
         <Number_of_Visits>{:d}</Number_of_Visits>
+              
         <Continuous_Visits>false</Continuous_Visits>   <!--  Irrelevant for nominal science observations  -->
+              
         <Priority>{:d}</Priority>
+              
         <Minimum_Effective_Duration unit="%">{:d}</Minimum_Effective_Duration>
+              
         <Send_Data_Taking_During_SAA>false</Send_Data_Taking_During_SAA>
         <Send_Data_Taking_During_Earth_Constraints>false</Send_Data_Taking_During_Earth_Constraints>
-        <PITL>true</PITL>
+        <PITL>{}</PITL>
         </Non_Time_Critical_Request>
     </List_of_Non_Time_Critical_Requests>
   </Data_Block>
@@ -472,6 +557,12 @@ def _make_list_of_phase_ranges(Num_Ranges,
 
     return ""
 
+def _pitl_string(gmag):
+    if gmag > 11:
+        return 'false'
+    else:
+        return 'true'
+
 
 
 def _parcheck_non_time_critical(Priority, MinEffDur, 
@@ -497,7 +588,7 @@ def _parcheck_non_time_critical(Priority, MinEffDur,
 def _parcheck_time_critical(Priority, MinEffDur,
         Earliest_start_date, Latest_end_date,
         Earliest_start_phase, Latest_start_phase, 
-        Period, Num_Ranges, 
+        Period, Num_Ranges, T_visit,
         BegPh1, EndPh1, Effic1,
         BegPh2, EndPh2, Effic2):
 
@@ -525,6 +616,11 @@ def _parcheck_time_critical(Priority, MinEffDur,
             Invalid efficiency for phase constraint 1
             """
 
+    if Period < (T_visit/86400.0):
+        return """
+        Visit_Duration should always be shorter than the Transit_Period.
+        """
+
     if abs(Num_Ranges) > 1:
         if (BegPh2 < 0) or (BegPh2 > 1) or (EndPh2 < 0) or (EndPh2 > 1):
             return """
@@ -540,7 +636,7 @@ def _parcheck_time_critical(Priority, MinEffDur,
 
 def _target_table_row_to_xml(row, progamme_id=0,
         proprietary_first=547, proprietary_last=365, 
-        checker=False, user_g_mag=False):
+        user_g_mag=False):
 
     period = row['Period'] 
     t_exp = row['T_exp']
@@ -561,22 +657,16 @@ def _target_table_row_to_xml(row, progamme_id=0,
         gmag = row['dr2_g_mag']
         e_gmag = row['e_dr2_g_mag']
 
-    if checker:
-        try:
-            key = re.match('[AFGKM][0-9]', row['SpTy'])[0]
-            GV = SpTypeToGminusV[key]
-        except TypeError:
-            GV = -0.15
-        mag, e_mag = gmag-GV, e_gmag
-    else:
-        mag, e_mag = gmag, e_gmag
+    # Probably not a good idea to have this appear as 0.000 in the output
+    if e_gmag < 0.001: 
+        e_gmag = 0.001
 
     if period > 0:
         error = _parcheck_time_critical(
                 row['Priority'], row['MinEffDur'],
                 row['BJD_early'], row['BJD_late'],
                 row['Ph_early'], row['Ph_late'],
-                period, row['N_Ranges'],
+                period, row['N_Ranges'], row['T_visit'],
                 row["BegPh1"], row["EndPh1"], row["Effic1"],
                 row["BegPh2"], row["EndPh2"], row["Effic2"])
 
@@ -585,10 +675,11 @@ def _target_table_row_to_xml(row, progamme_id=0,
                 .format(row['ObsReqName'],error))
 
         xml = _xml_time_critical_fmt.format(
+              __version__, 
               _creation_time_string(),
               progamme_id, proprietary_first, proprietary_last,
               row['Target'], row['Gaia_DR2'], row['SpTy'],
-              mag, e_mag,
+              gmag, e_gmag,
               _choose_romode(t_exp),
               radeg, dedeg, row['pmra'], row['pmdec'],
               row['parallax'], row['T_eff'], 
@@ -600,7 +691,8 @@ def _target_table_row_to_xml(row, progamme_id=0,
               row['Ph_early'], row['Ph_late'],
               _make_list_of_phase_ranges(row['N_Ranges'],
                   row["BegPh1"], row["EndPh1"], row["Effic1"],
-                  row["BegPh2"], row["EndPh2"], row["Effic2"])
+                  row["BegPh2"], row["EndPh2"], row["Effic2"]),
+              _pitl_string(gmag) 
               )
       
     else:
@@ -613,22 +705,21 @@ def _target_table_row_to_xml(row, progamme_id=0,
                 .format(row['ObsReqName'],error))
 
         xml = _xml_non_time_critical_fmt.format(
+              __version__, 
               _creation_time_string(),
               progamme_id, proprietary_first, proprietary_last,
               row['Target'], row['Gaia_DR2'], row['SpTy'],
-              mag, e_mag,
+              gmag, e_gmag,
               _choose_romode(t_exp),
               radeg, dedeg, row['pmra'], row['pmdec'],
               row['parallax'], row['T_eff'],
               row['BJD_early'], row['BJD_late'], t_exp,
               n_stack_image, n_stack_imagettes,
               row['T_visit'], row['N_Visits'], row['Priority'],
-              row['MinEffDur']
+              row['MinEffDur'],
+              _pitl_string(gmag)
               )
 
-    if checker:
-        xml = xml.replace('Target_Magnitude','Target_Vmagnitude')
-
     return xml
 
 def main():
@@ -852,14 +943,6 @@ def main():
         help='Overwrite existing output files.'
     )
 
-    parser.add_argument('-c', '--checker', 
-        action='store_const',
-        dest='checker',
-        const=True,
-        default=False,
-        help='Output XML suitable for use with Scheduling Feasibility Checker'
-    )
-
     parser.add_argument('-x', '--suffix', 
         default='_EXT_APP_ObservationRequests.xml', type=str,
         help='''
@@ -1074,11 +1157,11 @@ def main():
                     progamme_id=args.programme_id, 
                     proprietary_first=args.proprietary_first,
                     proprietary_last=args.proprietary_last,
-                    checker=args.checker, user_g_mag=args.user_g_mag)
+                    user_g_mag=args.user_g_mag)
             )
         f.close()
 
-        vis = visibility(coords.ra.degree,coords.dec.degree)
+        vis = visibility(coords.ra.degree,coords.dec.degree,_G)
         if vis < 50:
             flags += 256
         if vis == 0:
